@@ -1374,6 +1374,8 @@ legitimate_model_name <- function(name, obfuscate_name = TRUE) {
 boost_url <- function() {"http://www.boost.org/users/download/"}
 
 makeconf_path <- function() {
+  RMU <- Sys.getenv("R_MAKEVARS_USER")
+  if (!is.na(RMU) && RMU != "") return(RMU)
   arch <- .Platform$r_arch
   if (arch == '')
     return(file.path(R.home(component = 'etc'), 'Makeconf'))
@@ -1648,8 +1650,11 @@ throw_sampler_warnings <- function(object) {
   if (is_sfinstance_valid(object) && all(sapply(sp, function(x) "energy__" %in% colnames(x)))) {
     E <- as.matrix(sapply(sp, FUN = function(x) x[,"energy__"]))
     threshold <- 0.3
-    EBFMI <- get_num_upars(object) / apply(E, 2, var)
-    n_e <- sum(EBFMI < threshold, na.rm = TRUE)
+    if (nrow(E) > 1) {
+      EBFMI <- get_num_upars(object) / apply(E, 2, var)
+      n_e <- sum(EBFMI < threshold, na.rm = TRUE)
+    }
+    else n_e <- 0L
     if (n_e > 0)
       warning("There were ", n_e, 
               " chains where the estimated Bayesian Fraction of Missing Information",
