@@ -39,7 +39,9 @@ SEXP seq_permutation(SEXP conf);
 SEXP CPP_read_comments(SEXP file, SEXP n);
 SEXP stan_prob_autocovariance(SEXP v);
 SEXP is_Null_NS(SEXP ns);
-SEXP CPP_stanc280(SEXP model_stancode, SEXP model_name, SEXP allow_undefined);
+SEXP CPP_stanc280(SEXP model_stancode, SEXP model_name, 
+                  SEXP allow_undefined, SEXP include_paths);
+SEXP stanfuncs(SEXP model_stancode, SEXP model_name, SEXP allow_undefined);
 SEXP CPP_stan_version();
 SEXP extract_sparse_components(SEXP A);
 
@@ -58,7 +60,8 @@ static const R_CallMethodDef CallEntries[] = {
   CALLDEF(CPP_read_comments, 2),
   CALLDEF(stan_prob_autocovariance, 1),
   CALLDEF(is_Null_NS, 1),
-  CALLDEF(CPP_stanc280, 3),
+  CALLDEF(CPP_stanc280, 4),
+  CALLDEF(stanfuncs, 3),
   CALLDEF(CPP_stan_version, 0),
   CALLDEF(extract_sparse_components, 1),
   {NULL, NULL, 0}
